/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/* Nome: 0006_DENSTPO_USR_EXPORTAPEDOL_DENADAI.sql                            */
/*                                                                            */
/* Descrio:                                                                 */
/* Procedure destinada a possibilitar que os pedidos do OL                    */
/* (Operador Logstico) geradas pelo sistema da Teknisa sejam importadas      */
/* no sistema da Microsiga e, para isso, a procedure alimentar duas tabelas  */
/* intermedirias entre os dois sistemas (tabelas pertencentes ao banco de    */
/* dados do sistema da Microsiga).                                            */
/* Criao:                                                                   */
/* 26/08/2008 - Raquel Cunha                                                  */
/******************************************************************************/

CREATE OR REPLACE
PROCEDURE USR_EXPORTAPEDOL_DENADAI IS
   V_DTGRV         DATE;
   V_HRGRV         VARCHAR2(04);

   V_FILIAL        VARCHAR(10);
   V_FORMPGTO      VARCHAR(3);
   V_FORNECEDOR    VARCHAR(14);
   V_NUM6          INTEGER;
   V_NRSEQ         VARCHAR(3);
   V_CUSTO         FLOAT;
   V_NRTIPOCUST    VARCHAR2(2);
   V_VALOR         FLOAT;
   V_PRODINTE      VARCHAR(20);
   V_PRODESTO      VARCHAR(10);
   V_CULTLIST      FLOAT;

   V_NOVOCODIGO    INTEGER;
BEGIN
   V_DTGRV := NULL;
   V_HRGRV := NULL;

   V_NRSEQ := '001';

   /* Retorna data e hora de exportao */
   BEGIN
      SELECT TO_DATE(SYSDATE), TO_CHAR(SYSDATE,'HH24MI')
        INTO V_DTGRV, V_HRGRV
        FROM DUAL;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_DTGRV := NULL;
         V_HRGRV := NULL;
   END;

   FOR C_PEDOLEXPORT IN
      (SELECT P.CDFILDEST, P.CDFILLANC, P.NRPEDEXOL,
              P.DTPEDEXOL, P.CDFILIOPELOG,
              P.CDEMPRESA
         FROM PEDIDOEXOL P, (SELECT DISTINCT(CDFILIAL)
                               FROM FILGRUPFILI
                              WHERE USR_IDPROTHEUS = 'S') F
        WHERE P.USR_DTEXPORTA IS NULL
          AND P.CDFILDEST = F.CDFILIAL
        ORDER BY P.CDFILDEST, P.CDFILLANC, P.NRPEDEXOL)
   LOOP
      SELECT MAX(CDGRUPFILI)
        INTO V_FILIAL
        FROM FILGRUPFILI
       WHERE CDFILIAL = C_PEDOLEXPORT.CDFILLANC
         AND USR_IDPROTHEUS = 'S';

      IF NOT V_FILIAL IS NULL THEN

         SELECT LPAD(MAX(F.CDFORMPGTO),3,'0'),
                SUBSTR(replace(replace(replace(MAX(F.NRINSJURFORN), '-', ''),'.',''),'/',''),1,14)
           INTO V_FORMPGTO,
                V_FORNECEDOR
           FROM FORNECEDOR F, FILIAL FI
          WHERE FI.CDFILIAL = C_PEDOLEXPORT.CDFILIOPELOG
            AND F.CDFORNECED = FI.CDFORNOPELOG;

         /* Verifica existncia do pedido de venda */
         SELECT NVL(MAX(W6_IDAFPVC),0)
           INTO V_NUM6
           FROM USR_ZW6
          WHERE CDFILDEST = C_PEDOLEXPORT.CDFILDEST
            AND CDFILLANC = C_PEDOLEXPORT.CDFILLANC
            AND NRPEDEXOL = C_PEDOLEXPORT.NRPEDEXOL
            AND ORIGPEDIDO = 'P'
            AND W6_TPEDI = '1';

         /* Retorna o sequencial para a tabela */
         BEGIN
            SELECT W6_IDAFPVC.NEXTVAL
              INTO V_NOVOCODIGO
              FROM DUAL;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_NOVOCODIGO := 1;
         END;

         IF V_NUM6 = 0 THEN
            INSERT INTO USR_ZW6
                (CDFILDEST, CDFILLANC, NRPEDEXOL, W6_IDAFPVC,
                 W6_EMPRESA, W6_FILIAL, W6_NUM,
                 W6_CGC, W6_CC, W6_CONDPAG, W6_TIPO, W6_TPEDI, ORIGPEDIDO,
                 W6_DTGRV, W6_HRGRV, W6_DTIMP, W6_HRIMP)
            VALUES
                (C_PEDOLEXPORT.CDFILDEST, C_PEDOLEXPORT.CDFILLANC, C_PEDOLEXPORT.NRPEDEXOL, V_NOVOCODIGO,
                 SUBSTR(V_FILIAL, 7, 2), SUBSTR(V_FILIAL, 9, 2),
                 SUBSTR(C_PEDOLEXPORT.NRPEDEXOL, 5, 6), V_FORNECEDOR,
                 C_PEDOLEXPORT.CDFILDEST, V_FORMPGTO, 'N', '1', 'P',
                 V_DTGRV, V_HRGRV, NULL, '');
         ELSE
            INSERT INTO USR_ZW6
                (CDFILDEST, CDFILLANC, NRPEDEXOL, W6_IDAFPVC,
                 W6_EMPRESA, W6_FILIAL, W6_NUM,
                 W6_CGC, W6_CC, W6_CONDPAG, W6_TIPO, W6_TPEDI, ORIGPEDIDO,
                 W6_DTGRV, W6_HRGRV, W6_DTIMP, W6_HRIMP)
            VALUES
                (C_PEDOLEXPORT.CDFILDEST, C_PEDOLEXPORT.CDFILLANC, C_PEDOLEXPORT.NRPEDEXOL, V_NOVOCODIGO,
                 SUBSTR(V_FILIAL, 7, 2), SUBSTR(V_FILIAL, 9, 2),
                 SUBSTR(C_PEDOLEXPORT.NRPEDEXOL, 5, 6), V_FORNECEDOR,
                 C_PEDOLEXPORT.CDFILDEST, V_FORMPGTO, 'N', '2', 'P',
                 V_DTGRV, V_HRGRV, NULL, '');

            FOR C_ITEXCL IN (SELECT CDPRODUTO, DTPROGENPEOL,
                                    W7_EMPRESA, W7_FILIAL, W7_NUM,
                                    W7_CGC, W7_ITEM, W7_PRODUTO, W7_CC, W7_QTDVEN,
                                    W7_PRCVEN, W7_PRUNIT, W7_VALOR
                               FROM USR_ZW7
                              WHERE CDFILDEST = C_PEDOLEXPORT.CDFILDEST
                                AND CDFILLANC = C_PEDOLEXPORT.CDFILLANC
                                AND NRPEDEXOL = C_PEDOLEXPORT.NRPEDEXOL
                                AND W7_IDAFPVI = V_NUM6
                              ORDER BY CDPRODUTO, DTPROGENPEOL) LOOP

               INSERT INTO USR_ZW7
                    (CDFILDEST, CDFILLANC, NRPEDEXOL, CDPRODUTO, DTPROGENPEOL,
                     W7_IDAFPVI, W7_EMPRESA, W7_FILIAL, W7_NUM,
                     W7_CGC, W7_ITEM, W7_PRODUTO, W7_CC, W7_QTDVEN,
                     W7_PRCVEN, W7_PRUNIT, W7_VALOR, W7_DTENTR, W7_TPEDI,
                     W7_DTGRV, W7_HRGRV, W7_DTIMP, W7_HRIMP)
               VALUES
                    (C_PEDOLEXPORT.CDFILDEST, C_PEDOLEXPORT.CDFILLANC, C_PEDOLEXPORT.NRPEDEXOL,
                     C_ITEXCL.CDPRODUTO, C_ITEXCL.DTPROGENPEOL,
                     V_NOVOCODIGO, C_ITEXCL.W7_EMPRESA, C_ITEXCL.W7_FILIAL, C_ITEXCL.W7_NUM,
                     C_ITEXCL.W7_CGC, C_ITEXCL.W7_ITEM, C_ITEXCL.W7_PRODUTO, C_ITEXCL.W7_CC, C_ITEXCL.W7_QTDVEN,
                     C_ITEXCL.W7_PRCVEN, C_ITEXCL.W7_PRUNIT, C_ITEXCL.W7_VALOR, C_ITEXCL.DTPROGENPEOL, '2', V_DTGRV,
                     V_HRGRV, NULL, '');
            END LOOP;

            /* Retorna o sequencial para a tabela */
            BEGIN
               SELECT W6_IDAFPVC.NEXTVAL
                 INTO V_NOVOCODIGO
                 FROM DUAL;
            EXCEPTION
               WHEN NO_DATA_FOUND THEN
                  V_NOVOCODIGO := 1;
            END;

            INSERT INTO USR_ZW6
                (CDFILDEST, CDFILLANC, NRPEDEXOL, W6_IDAFPVC,
                 W6_EMPRESA, W6_FILIAL, W6_NUM,
                 W6_CGC, W6_CC, W6_CONDPAG, W6_TIPO, W6_TPEDI, ORIGPEDIDO,
                 W6_DTGRV, W6_HRGRV, W6_DTIMP, W6_HRIMP)
            VALUES
                (C_PEDOLEXPORT.CDFILDEST, C_PEDOLEXPORT.CDFILLANC, C_PEDOLEXPORT.NRPEDEXOL, V_NOVOCODIGO,
                 SUBSTR(V_FILIAL, 7, 2), SUBSTR(V_FILIAL, 9, 2),
                 SUBSTR(C_PEDOLEXPORT.NRPEDEXOL, 5, 6), V_FORNECEDOR,
                 C_PEDOLEXPORT.CDFILDEST, V_FORMPGTO, 'N', '1', 'P',
                 V_DTGRV, V_HRGRV, NULL, '');
         END IF;

         FOR C_ITEMPEDEXOL IN
            (SELECT CDPRODUTO, DTPROGENPEOL, SUM(QTPROGENPEOL) AS QTPROGENPEOL
               FROM ITEMPEDEXOL
              WHERE CDFILDEST = C_PEDOLEXPORT.CDFILDEST
                AND CDFILLANC = C_PEDOLEXPORT.CDFILLANC
                AND NRPEDEXOL = C_PEDOLEXPORT.NRPEDEXOL
              GROUP BY CDPRODUTO, DTPROGENPEOL
              ORDER BY CDPRODUTO, DTPROGENPEOL)
         LOOP
            BEGIN
               SELECT CDARVPROD,
                      CDPRODESTO
                 INTO V_PRODINTE,
                      V_PRODESTO
                 FROM PRODUTO
                WHERE CDPRODUTO = C_ITEMPEDEXOL.CDPRODUTO;
            EXCEPTION
               WHEN NO_DATA_FOUND THEN
                  V_PRODINTE := NULL;
                  V_PRODESTO := NULL;
            END;

            BEGIN
               SELECT CDTIPCUSTEST
                 INTO V_NRTIPOCUST
                 FROM PARAMFILIAL
                WHERE CDFILIAL = C_PEDOLEXPORT.CDFILDEST;
            EXCEPTION
               WHEN NO_DATA_FOUND THEN
                  V_NRTIPOCUST := NULL;
            END;

            IF V_NRTIPOCUST IS NULL THEN
               V_NRTIPOCUST := '03';
            END IF;

            V_CUSTO := CUSTO_PRODUTO(C_PEDOLEXPORT.CDFILDEST, V_PRODESTO,
                                     V_NRTIPOCUST, C_ITEMPEDEXOL.DTPROGENPEOL, SYSDATE);

            V_CULTLIST := CUSTO_PRODUTO(C_PEDOLEXPORT.CDFILIOPELOG, V_PRODESTO,
                                        '06', C_ITEMPEDEXOL.DTPROGENPEOL, SYSDATE);

            V_VALOR := C_ITEMPEDEXOL.QTPROGENPEOL*V_CUSTO;

            INSERT INTO USR_ZW7
                 (CDFILDEST, CDFILLANC, NRPEDEXOL, CDPRODUTO, DTPROGENPEOL,
                  W7_IDAFPVI, W7_EMPRESA, W7_FILIAL, W7_NUM,
                  W7_CGC, W7_ITEM, W7_PRODUTO, W7_CC, W7_QTDVEN,
                  W7_PRCVEN, W7_PRUNIT, W7_VALOR, W7_DTENTR, W7_TPEDI,
                  W7_DTGRV, W7_HRGRV, W7_DTIMP, W7_HRIMP)
            VALUES
                 (C_PEDOLEXPORT.CDFILDEST, C_PEDOLEXPORT.CDFILLANC, C_PEDOLEXPORT.NRPEDEXOL,
                  C_ITEMPEDEXOL.CDPRODUTO, C_ITEMPEDEXOL.DTPROGENPEOL,
                  V_NOVOCODIGO, SUBSTR(V_FILIAL, 7, 2), SUBSTR(V_FILIAL, 9, 2),
                  SUBSTR(C_PEDOLEXPORT.NRPEDEXOL, 5, 6),
                  V_FORNECEDOR, V_NRSEQ, SUBSTR(V_PRODINTE, 1, 15),
                  C_PEDOLEXPORT.CDFILDEST, ROUND(C_ITEMPEDEXOL.QTPROGENPEOL,2),
                  ROUND(V_CUSTO,6), ROUND(V_CULTLIST,6), ROUND(V_VALOR,2), C_ITEMPEDEXOL.DTPROGENPEOL, '1', V_DTGRV,
                  V_HRGRV, NULL, '');

            V_NRSEQ := LPAD(RTRIM(TO_CHAR(TO_NUMBER(RTRIM(V_NRSEQ))+ 1)),3,'0');
         END LOOP;

         UPDATE PEDIDOEXOL
            SET USR_DTEXPORTA = SYSDATE
          WHERE CDFILDEST = C_PEDOLEXPORT.CDFILDEST
            AND CDFILLANC = C_PEDOLEXPORT.CDFILLANC
            AND NRPEDEXOL = C_PEDOLEXPORT.NRPEDEXOL;

         V_NRSEQ := '001';
      END IF;
   END LOOP;
   COMMIT;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('USR_EXPORTAPEDOL_DENADAI','5.50.XXX'); END;
/
